@@ -12,7 +12,7 @@ from sky_api_client.entity import event_participant  # noqa: F401
 from sky_api_client.entity import event_participant_fee  # noqa: F401
 from sky_api_client.entity import event_participant_fee_payment  # noqa: F401
 from sky_api_client.entity import event_participant_donation  # noqa: F401
-from sky_api_client.entity import event_participant_levels  # noqa: F401
+from sky_api_client.entity import event_participation_levels  # noqa: F401
 from sky_api_client.entity import gender  # noqa: F401
 from sky_api_client.entity import gift  # noqa: F401
 from sky_api_client.entity import gift_batch  # noqa: F401
