@@ -6,6 +6,4 @@ from sky_api_client.entity.registry import EntityRegistry
 class EventParticipantFeePayment(Entity):
     LIST_URL = '/event/v1/participants/{id}/feepayments'
     CREATE_URL = '/event/v1/participants/{id}/feepayments'
-    GET_URL = '/event/v1/participants/{parent_id}/feepayments/{id}'
-    UPDATE_URL = '/event/v1/participants/{parent_id}/feepayments/{id}'
-    DELETE_URL = '/event/v1/participants/{parent_id}/feepayments/{id}'
+    DELETE_URL = '/event/v1/participantfeepayments/{id}'
